#!/usr/bin/env python

from brain_games.game_engine import start_game
from brain_games.games.gcd import calculate_gcd


def main():
    start_game(calculate_gcd)


if __name__ == '__main__':
    main()



from random import randint


def calculate_progression():
    description = 'What number is missing in the progression?'
    pro_length = randint(5, 10)
    pro_begin = randint(1, 100)
    pro_step = randint(1, 10)
    miss_position = randint(0, pro_length - 1)
    i = 0
    next = pro_begin
    str_accumulative = str(next)
    miss_begin = 0
    miss_end = 0 + len(str(next))
    while i <= pro_length - 1:
        if i == miss_position:
            result = str(next)
            miss_begin = len(str_accumulative) - len(str(next))
            miss_end = miss_begin + len(str(next)) - 1
        if i != pro_length - 1:
            next = next + pro_step
            str_accumulative += f' {str(next)}'
        i += 1
    progression_str = (f'{str_accumulative[:miss_begin]}..'
                       f'{str_accumulative[miss_end + 1:]}')
    return(description, progression_str, str(result))



from random import randint


def calculate_even():
    description = 'Answer "yes" if the number is even, otherwise answer "no".'
    number = randint(1, 1000)
    if number % 2 == 0:
        result = 'yes'
    else:
        result = 'no'
    return (description, str(number), result)



from random import randint


def calculate_prime():
    description = (
        'Answer "yes" if given number is prime. Otherwise answer "no".')
    number = randint(1, 1000)
    i = number // 2
    result = 'yes'
    number_str = str(number)
    while i > 1:
        if number % i == 0:
            result = 'no'
        i = i - 1
    return(description, number_str, str(result))



#!/usr/bin/env python

from brain_games.game_engine import start_game
from brain_games.games.prime import calculate_prime


def main():
    start_game(calculate_prime)


if __name__ == '__main__':
    main()



from random import randint


def calculate_gcd():
    description = 'Find the greatest common divisor of given numbers.'
    number1 = randint(1, 100)
    number2 = randint(1, 100)
    numbers_str = f'{number1} {number2}'
    minimum = min(number1, number2)
    result = 1
    while minimum >= 1:
        if (number1 % minimum == 0) and (number2 % minimum == 0):
            result = minimum
            break
        minimum -= 1
    return(description, numbers_str, str(result))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['brain_games', 'brain_games.games', 'brain_games.scripts']

package_data = \
{'': ['*']}

install_requires = \
['prompt>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['brain-calc = brain_games.scripts.brain_calc:main',
                     'brain-even = brain_games.scripts.brain_even:main',
                     'brain-games = brain_games.scripts.brain_games:main',
                     'brain-gcd = brain_games.scripts.brain_gcd:main',
                     'brain-prime = brain_games.scripts.brain_prime:main',
                     'brain-progression = '
                     'brain_games.scripts.brain_progression:main']}

setup_kwargs = {
    'name': 'hexlet-code-dddarknight',
    'version': '0.1.0',
    'description': 'Provides oppotunity to play games with mathematical calculations. In version 0.1.0 there are 5 games: calculations of two numbers, identification of an even number, finding the greatest common divisor of given numbers, identification of a prime number, finding missing number in the progression.',
    'long_description': '# Brain Games\nBrain Games is a Python library that provides oppotunity to play games with mathematical calculations.\n\n____\n\n### Hexlet tests and linter status:\n[![Actions Status](https://github.com/Dddarknight/python-project-lvl1/workflows/hexlet-check/badge.svg)](https://github.com/Dddarknight/python-project-lvl1/actions)\n\n![Linter](https://github.com/Dddarknight/python-project-lvl1/actions/workflows/linter.yml/badge.svg)\n\n### CodeClimate:\n<a href="https://codeclimate.com/github/Dddarknight/python-project-lvl1/maintainability"><img src="https://api.codeclimate.com/v1/badges/f0825e54a6e1af78ca05/maintainability" /></a>\n\n## Links\nThis project was built using these tools:\n| Tool | Description |\n|----------|---------|\n| [poetry](https://python-poetry.org/) |  "Python dependency management and packaging made easy" |\n\n## Description\nIn each game you have to give 3 right answers to become a winner, otherwise the game ends. \nYou can play any of the following games:\n| Game name | Description |\n|----------|---------|\n| brain-calc | You need to make calculations with 2 given numbers|\n| brain-even | You need to answer whether the given number is even or not|\n| brain-gcd | You need to find the greatest common divisor of given numbers|\n| brain-prime | You need to answer whether the given number is prime or not|\n| brain-progression | You need to find the missing number in the progression|\n\n\n## Usage\n```\n$ brain-calc\n$ brain-even\n$ brain-gcd\n$ brain-prime\n$ brain-progression\n```\n\n### Asciinema record:\n[![asciinema](https://asciinema.org/a/uESMOk94NHGA705nEkQGoNAQh)](https://asciinema.org/a/uESMOk94NHGA705nEkQGoNAQh)\n\n## License\n[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)\n',
    'author': 'Dddarknight',
    'author_email': '9801677@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Dddarknight/python-project-lvl1',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.10,<4.0.0',
}


setup(**setup_kwargs)



from random import randint


def calculate_numbers():
    description = 'What is the result of the expression?'
    number1 = randint(1, 100)
    number2 = randint(1, 100)
    choice = randint(1, 3)
    choice_plus = 1
    choice_minus = 2
    if choice == choice_plus:
        result = number1 + number2
        expression_str = f'{number1} + {number2}'
    elif choice == choice_minus:
        result = number1 - number2
        expression_str = f'{number1} - {number2}'
    else:
        result = number1 * number2
        expression_str = f'{number1} * {number2}'
    return (description, expression_str, str(result))



import prompt
from brain_games.cli import welcome_user


def start_game(calculate_result):
    print('Welcome to the Brain Games!')
    name = welcome_user()
    attempt_number = 1
    max_attempts = 3
    while attempt_number <= max_attempts:
        (game_description, question, result) = calculate_result()
        if attempt_number == 1:
            print(game_description)
        print(f'Question: {question}')
        answer = prompt.string('Your answer: ')
        if answer != result:
            print(f'{answer} is wrong answer ;(. Correct answer was {result}'
                  f"Let's try again, {name}!")
            return
        else:
            print('Correct')
        attempt_number += 1
    print(f'Congratulations, {name}!')
